@@ -37,17 +37,26 @@ class TextFileService:
             return False
         
     def get_file_content(self, source_path: str, file_name: str = None):
-        '''
-        source_path = folder or file path where the content is stored;
-        file_name = in case source_path is a folder, the file name can be specified here;
-        '''
+        """
+        Reads the content of a file.
+
+        Parameters:
+            source_path (str): Folder or file path where the content is stored.
+            file_name (str, optional): If source_path is a folder, specify the file name.
+
+        Returns:
+            str: Content of the file if it exists, None otherwise.
+        """
         file_path = source_path
-        
+
         if file_name is not None:
             file_path = os.path.join(source_path, file_name)
-        
-        with open(file_path, "r") as file:
-            return file.read()
+
+        try:
+            with open(file_path, "r") as file:
+                return file.read()
+        except FileNotFoundError:
+            return None
     
     def move_file(self, source_path: str, destination_folder: str, file_name: str = None, new_name: str = None):
         '''
